{Application 'CHECK' logic file generated by CSPro }
PROC GLOBAL
set explicit;
numeric i,chhtot, chhcmp, chhinc, chh12, chh13, cewmfnd, ciwmfnd, xewmfnd,
  xiwmfnd, chh14, chh15, cechfnd, cichfnd, xechfnd, xichfnd, wcluster, whnumber, 
  t, errorsfound;

function NAtoZero(xvar);
  if xvar = notappl then
    xvar = 0
  endif;
  NAtoZero = xvar;
end;

PROC MICS3_FF

{ 1th }
preproc

  { Cluster  Totals }
  chhtot  = 0;              {Total households                               }
  chhcmp  = 0;              {Total completed households                     }
  chhinc  = 0;              {Total incomplete households                    }
  chh12   = 0;              {Total eligible women from HH12                 }
  chh13   = 0;              {Total eligible women interviewed from HH13     }
  cewmfnd = 0;              {Total eligible women found                     }
  ciwmfnd = 0;              {Total interviewed women found                  }
  chh14   = 0;              {Total eligible children from HH14              }
  chh15   = 0;              {Total eligible children interviewed from HH15  }
  cechfnd = 0;              {Total eligible children found                  }
  cichfnd = 0;              {Total interviewed children found               }
  errorsfound = 0;			{Total errors found during structure check		}
 
{ 5th } 
postproc

  { Print out cluster questionnaire counts }
  write("                                                       ");
  write("                                                       ");
  write("=========================================================================");
  write("MICS Data Structure Check                              ");
  write("Cluster:   %d                                          ",wcluster);
  write("                                                       ");
  write("    Households    |         Women            |        Children    ");
  write("Total Comp Incomp |  Eligible    Interviewed |  Eligible    Interviewed");
  write("                  | HH12 FOUND   HH13  FOUND | HH14 FOUND   HH15  FOUND");
  write("%5d%5d%7d |%5d%6d%7d%7d |%5d%6d%7d%7d",
        chhtot,chhcmp,chhinc,chh12,cewmfnd,chh13,ciwmfnd,chh14,cechfnd,chh15,cichfnd);
  write("                                                       ");
  write("                                                       ");

  { check cluster's counts of women }
  if chh12  <> cewmfnd then
    errmsg(3101,wcluster,cewmfnd,chh12);
    errorsfound = errorsfound + 1;
  endif;
  if chh13  <> ciwmfnd then
    errmsg(3102,wcluster,ciwmfnd,chh13);
    errorsfound = errorsfound + 1;
  endif;
  
  { check cluster's counts of children }
  if chh14  <> cechfnd then
    errmsg(3201,wcluster,cechfnd,chh14);
    errorsfound = errorsfound + 1;
  endif;
  if chh15  <> cichfnd then
    errmsg(3202,wcluster,cichfnd,chh15);
    errorsfound = errorsfound + 1;
  endif;

  { check against cluster tracking info }
  TCLUSTER = HH1;
  t = loadcase(cluster_tracking_dict, TCLUSTER);
  if t then
  	{ Check that number of found hh questionnaires is the same as in tracking info }
  	if TNUMHHQUEST <> chhtot then
  		errmsg(3301, TCLUSTER, chhtot, TNUMHHQUEST);
	    errorsfound = errorsfound + 1;
  	endif;
  	
  	{ Check that number of completed hh questionnaires is the same as in tracking info }
  	if TNUMHHCOMP <> chhcmp then
  		errmsg(3302, TCLUSTER, chhcmp, TNUMHHCOMP);
	    errorsfound = errorsfound + 1;
  	endif;
  	
  	{ Check that number of found women questionnaires is the same as in tracking info }
  	if TNUMWMQUEST <> cewmfnd then
  		errmsg(3303, TCLUSTER, cewmfnd, TNUMWMQUEST);
  	    errorsfound = errorsfound + 1;
  	endif;
  	
  	{ Check that number of completed questionnaires is the same as in tracking info }
  	if TNUMWMCOMP <> ciwmfnd then
  		errmsg(3304, TCLUSTER, ciwmfnd, TNUMWMCOMP);
  	    errorsfound = errorsfound + 1;
	endif;

  	{ Check that number of found questionnaires is the same as in tracking info }
  	if TNUMCHQUEST <> cechfnd then
  		errmsg(3305, TCLUSTER, cechfnd, TNUMCHQUEST);
  	    errorsfound = errorsfound + 1;
	endif;
  	
  	{ Check that number of completed questionnaires is the same as in tracking info }
  	if TNUMCHCOMP <> cichfnd then
  		errmsg(3306, TCLUSTER, cichfnd, TNUMCHCOMP);
  	    errorsfound = errorsfound + 1;
	endif;
	
	{ If no errors found, set structure check complete date in tracking info }
	if errorsfound = 0 then
		TCHECK = sysdate("DDMMYYYY");
		t = writecase(cluster_tracking_dict, tcluster);
		close(cluster_tracking_dict);
	endif;
  else 
  	errmsg(4001);
  endif;
  
  { Write summary to user }
  write("");
  write("============================================================");
  if errorsfound = 0 then
  	write("NO ERRORS FOUND --- PROCEED TO VERIFICATION DATA ENTRY");
  else
  	write("STRUCTURE ERRORS FOUND --- PLEASE CORRECT THE DATA FILE");
  endif;
  write("============================================================");
  write("");
  
PROC HH
{ 2rd } 
preproc
  wcluster = HH1;
  whnumber = HH2;
  xewmfnd = 0; { initialize household's count of women's questionnaires           }
  xiwmfnd = 0; { initialize household's count of completed women's interviews     }
  xechfnd = 0; { initialize household's count of children's questionnaires        }
  xichfnd = 0; { initialize household's count of completed children's interviews  }

  { Set cluster totals }
  chhtot   = chhtot + 1;
  if HH9 = 1 then
    chhcmp = chhcmp + 1
  else
    chhinc = chhinc + 1
  endif;
  chh12 = chh12 + NAtoZero(HH12);
  chh13 = chh13 + NAtoZero(HH13);
  chh14 = chh14 + NAtoZero(HH14);
  chh15 = chh15 + NAtoZero(HH15);

{ 4nd } 
postproc

  { Print out household questionnaire counts }
  write("                                                       ");
  write("                                                       ");
  write("=========================================================================");
  write("MICS Data Structure Check                              ");
  write("Household:   %d                                        ",whnumber);
  write("Result:      %d                                        ",HH9);
  write("                                                       ");
  if HH9 = 1 then
    write("        Women            |        Children    ");
    write(" Eligible    Interviewed |  Eligible    Interviewed");
    write("HH12 FOUND   HH13  FOUND | HH14 FOUND   HH15  FOUND");
    write("%5d%6d%7d%7d |%5d%6d%7d%7d",
          HH12,xewmfnd,HH13,xiwmfnd,HH14,xechfnd,HH15,xichfnd);
    write("                                                       ");
    write("                                                       ");
  endif;

  { check household's counts of women }
  if NAtoZero(HH12)  <> xewmfnd then
    errmsg(3111,hh2,xewmfnd,hh12);
    errorsfound = errorsfound + 1;
  endif;
  if NAtoZero(HH13)  <> xiwmfnd then
    errmsg(3112,hh2,xiwmfnd,hh13);
    errorsfound = errorsfound + 1;
  endif;

  { check household's counts of children }
  if NAtoZero(HH14)  <> xechfnd then
    errmsg(3211,hh2,xechfnd,hh14);
    errorsfound = errorsfound + 1;
  endif;
  if NAtoZero(HH15)  <> xichfnd then
    errmsg(3212,hh2,xichfnd,hh15);
    errorsfound = errorsfound + 1;
  endif;


PROC WMCH
{ 3th } 
preproc
  if HL6(LN) <> 0 then    { if this case is an eligible woman}
    cewmfnd = cewmfnd + 1;
    xewmfnd = xewmfnd + 1;
    if WM7 = 1 then { if interview completed}
      ciwmfnd = ciwmfnd + 1;
      xiwmfnd = xiwmfnd + 1;
    endif
  else                    { if this case is an eligible child}
    cechfnd = cechfnd + 1;
    xechfnd = xechfnd + 1;
    if UF9 = 1 then { if interview completed}
      cichfnd = cichfnd + 1;
      xichfnd = xichfnd + 1;
    endif
  endif;

